@@ -400,14 +400,14 @@ impl Allocator {
 impl UpdateList for FreeList {
     fn update(&mut self, size: u8, page: u64) -> PRes<u64> {
         let old = self.set(size, page);
-        debug_assert!(old != page, "freeing: {} already free: {} ", page, old);
+        debug_assert!(old != page || old == 0, "freeing: {} already free: {} ", page, old);
         Ok(old)
     }
 
     fn remove(&mut self, size: u8, page: u64, next: u64) -> PRes<()> {
         let old = self.set(size, next);
         debug_assert!(
-            old == page,
+            old == page || old == 0,
             "trimmed page not in top list expected:{} current:{} ",
             page,
             old
