@@ -396,16 +396,14 @@ impl IndexTransactionKeeper {
                                         return Err(PersyError::IndexDuplicateKey("".to_string(), format!("{}", k)));
                                     }
                                 }
-                                ValueMode::CLUSTER => {
-                                    if compare(&v, &add_value) == Ordering::Equal {
-                                        Value::SINGLE(v)
-                                    } else {
-                                        Value::CLUSTER(vec![v, add_value])
-                                    }
-                                }
+                                ValueMode::CLUSTER => match compare(&v, &add_value) {
+                                    Ordering::Equal => Value::SINGLE(v),
+                                    Ordering::Less => Value::CLUSTER(vec![v, add_value]),
+                                    Ordering::Greater => Value::CLUSTER(vec![add_value, v]),
+                                },
                             },
                             Value::CLUSTER(mut values) => {
-                                if let Ok(pos) = values.binary_search_by(|x| compare(x, &add_value)) {
+                                if let Err(pos) = values.binary_search_by(|x| compare(x, &add_value)) {
                                     values.insert(pos, add_value);
                                 }
                                 Value::CLUSTER(values)
