@@ -441,11 +441,15 @@ impl<K: IndexType, V: IndexOrd + Clone> Leaf<K, V> {
                     ValueMode::CLUSTER => {
                         let mut new_value = None;
                         match entry.value {
-                            Value::SINGLE(ref ev) => {
-                                if compare(ev, v) != Ordering::Equal {
+                            Value::SINGLE(ref ev) => match compare(ev, v) {
+                                Ordering::Equal => {}
+                                Ordering::Less => {
                                     new_value = Some(Value::CLUSTER(vec![ev.clone(), v.clone()]));
                                 }
-                            }
+                                Ordering::Greater => {
+                                    new_value = Some(Value::CLUSTER(vec![v.clone(), ev.clone()]));
+                                }
+                            },
                             Value::CLUSTER(ref mut cl) => {
                                 if let Err(index) = cl.binary_search_by(|x| compare(x, v)) {
                                     cl.insert(index, v.clone());
