@@ -1930,7 +1930,7 @@ impl Drop for SnapshotInt {
 
 #[cfg(test)]
 mod tests {
-    use super::{Config, Persy, TransactionConfig};
+    use super::{Config, OpenOptions, Persy, PersyError, TransactionConfig};
     use std::fs;
     #[test]
     pub fn test_recover_prepared_tx() {
@@ -2102,4 +2102,36 @@ mod tests {
 
         fs::remove_file("./target/test_recover_tx_choice.persy").unwrap();
     }
+
+    #[test]
+    pub fn test_read_id_out_of_file() {
+        let persy = OpenOptions::new().memory().unwrap();
+        let mut tx = persy.begin().unwrap();
+        tx.create_segment("test").unwrap();
+        let finalizer = tx.prepare().unwrap();
+        finalizer.commit().unwrap();
+        let id = crate::PersyId(crate::id::RecRef { page: 10000, pos: 10 });
+        let read_after = persy.read("test", &id).unwrap();
+        assert!(read_after.is_none());
+    }
+
+    #[test]
+    pub fn test_read_id_out_of_page() {
+        let persy = OpenOptions::new().memory().unwrap();
+        let mut tx = persy.begin().unwrap();
+        tx.create_segment("test").unwrap();
+        let id = tx.insert("test", &[0; 10]).unwrap();
+        let finalizer = tx.prepare().unwrap();
+        finalizer.commit().unwrap();
+        let id = crate::PersyId(crate::id::RecRef {
+            page: id.0.page,
+            pos: 2000,
+        });
+        let read_after = persy.read("test", &id);
+        assert!(read_after.is_err());
+        match read_after.err() {
+            Some(PersyError::InvalidId(_)) => {}
+            _ => assert!(false, "wrong error type"),
+        }
+    }
 }
