@@ -173,6 +173,11 @@ fn entry_exits(flags: u8) -> bool {
 
 impl<T: InfallibleRead + PageOps> SegmentPageRead for T {
     fn segment_read_entry(&mut self, segment_id: SegmentId, pos: u32) -> PRes<Option<(u64, u16)>> {
+        if pos > ADDRESS_PAGE_SIZE - ADDRESS_ENTRY_SIZE {
+            return Err(PersyError::InvalidId(
+                "Id page position too big than what expected".to_owned(),
+            ));
+        }
         self.seek(SEGMENT_HASH_OFFSET);
         let persistent_id = SegmentId::read(self);
         if persistent_id != segment_id {
